document.addEventListener('DOMContentLoaded', () => {
  const langToggle = document.getElementById('langToggle');
  const themeToggle = document.getElementById('themeToggle');
  const newsContainer = document.getElementById('newsContainer');
  let currentLang = 'en';
  
  // Language Toggle
  langToggle.addEventListener('click', () => {
    currentLang = currentLang === 'en' ? 'zh' : 'en';
    langToggle.querySelector('.lang-text').textContent = currentLang.toUpperCase();
    fetchAndDisplayNews();
  });

  // Theme Toggle
  themeToggle.addEventListener('click', () => {
    document.body.dataset.theme = document.body.dataset.theme === 'dark' ? 'light' : 'dark';
    themeToggle.querySelector('.theme-icon').textContent = 
      document.body.dataset.theme === 'dark' ? '🌙' : '☀️';
  });

  // Filter Buttons
  document.querySelectorAll('.filter-btn').forEach(btn => {
    btn.addEventListener('click', (e) => {
      document.querySelectorAll('.filter-btn').forEach(b => b.classList.remove('active'));
      e.target.classList.add('active');
      fetchAndDisplayNews(e.target.dataset.region);
    });
  });

  // Search Implementation
  let searchTimeout;
  const searchInput = document.getElementById('newsSearch');
  searchInput.addEventListener('input', (e) => {
    clearTimeout(searchTimeout);
    searchTimeout = setTimeout(() => {
      const searchTerm = e.target.value.trim();
      filterNews(searchTerm);
    }, 300);
  });

  // Mock news data - In real implementation, this would be fetched from an API
  async function fetchAndDisplayNews(region = 'all') {
    const mockNews = [
      {
        title: {
          en: "Global Climate Summit Announces New Targets",
          zh: "全球气候峰会宣布新目标"
        },
        summary: {
          en: "World leaders agree on ambitious new climate goals at COP28",
          zh: "世界各国领导人在COP28上就新的气候目标达成一致"
        },
        source: "https://example.com/news/1"
      },
      // Add more mock news items here
    ];

    displayNews(mockNews);
  }

  function displayNews(news) {
    newsContainer.innerHTML = news.map(item => `
      <article class="news-card">
        <div class="news-content">
          <h2 class="news-title">${item.title[currentLang]}</h2>
          <p class="news-summary">${item.summary[currentLang]}</p>
          <a href="${item.source}" class="news-link" target="_blank" rel="noopener">
            ${currentLang === 'en' ? 'Read More' : '阅读更多'}
          </a>
        </div>
      </article>
    `).join('');
  }

  function filterNews(searchTerm) {
    // Implementation for news filtering based on search term
  }

  // Initial news load
  fetchAndDisplayNews();
});
